@@ -1,20 +1,28 @@
-( cd opt/kde/share/doc/HTML/it/kchart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kchart ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kformula ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kformula ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kexi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kexi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kivio ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kivio ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/koffice ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/koffice ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/koshell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/koshell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kpresenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kpresenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kspread ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kspread ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/krita ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/krita ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kugar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kugar ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kword ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/koffice ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/koffice ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/koshell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/koshell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kspread ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kspread ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/karbon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/karbon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kchart ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kpresenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kpresenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kplato ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kplato ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/thesaurus ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kformula ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kformula ; ln -sf /opt/kde/share/doc/HTML/it/common common )
